Crate sigma_types_macros

Crate sigma_types_macros 

Macros that expand the power and usefulness of the sigma-types crate.

Attribute Macros

forall
Add a test that ensures that this type signature holds for all possible inputs.